@@ -8,8 +8,8 @@ from grtoolkit.Storage import File
 from grtoolkit.PowerPoint import duplicate_slide
 
 # parent = dirname(sys.argv[0])
-# parent = os.getcwd()
-parent = r"D:\OneDrive\Development\Life\The Truth"
+parent = os.getcwd()
+# parent = r"D:\OneDrive\Development\Life\The Truth"
 QUOTES = f'{parent}\\Quotes.txt'
 OLD_PPT = f'{parent}\\QUOTE_PPT_TEMPLATE.pptm'
 NEW_PPT = f'{parent}\\QUOTE_NEW.pptm'
@@ -19,17 +19,7 @@ NEW_PPT = f'{parent}\\QUOTE_NEW.pptm'
 prs = Presentation(OLD_PPT)
 
 QUOTESContent = File(QUOTES, enc=1).read()
-QUOTESList = QUOTESContent.decode(encoding="utf-8").split("\n\n")
-
-#DUPLICATE PPT SLIDE FOR EVERY 
-# for i in range (1,len(QUOTESList)):
-#     duplicate_slide(prs,0)
-
-# i = 0
-# for quote in QUOTESList:
-#     if i>0:
-#         duplicate_slide(prs,0)
-#     i=i+1
+QUOTESList = QUOTESContent.split("\n\n")
 
 #DUPLICATE SLIDE 0 FROM TEMPLATE
 duplicate_slide(prs,0,len(QUOTESList)-1)
